Installing StoryPy
==================

Installation of StoryPy can be done using Python's ``pip`` package manager.

From PyPI
---------

To install StoryPy via the Python Package Index, follow the steps described below, depending on your platform.

Unix-based
^^^^^^^^^^

Run the following command in the terminal::

    pip3 install storypy

Windows
^^^^^^^

Run the following command in the terminal::

    pip install storypy

Directly from wheel
-------------------

To install StoryPy from the wheel source, follow the steps described below, depending on your platform.

Unix-based
^^^^^^^^^^

1. Download the latest supported version of StoryPy from `the GitHub repository releases page <https://github.com/storypy/storypy/releases>`__, named something like ``storypy-[version]-py3-none-any.whl``.
2. Navigate to the directory containing the downloaded wheel.
3. Run the following command in the terminal (make sure to replace ``[version]`` with the actual version number of the downloaded wheel)::

    pip3 install storypy-[version]-py3-none-any.whl

Windows
^^^^^^^

1. Download the latest supported version of StoryPy from `the GitHub repository releases page <https://github.com/storypy/storypy/releases>`__, named something like ``storypy-[version]-py3-none-any.whl``.
2. Navigate to the directory containing the downloaded wheel.
3. Run the following command in the terminal (make sure to replace ``[version]`` with the actual version number of the downloaded wheel)::

    pip install storypy-[version]-py3-none-any.whl

